#!/usr/bin/env python

import logging
import os

from pygments import highlight
from pygments.filters import ErrorToken
from pygments.formatters import HtmlFormatter
from pygments.lexers import get_lexer_by_name


def test_highlight(test_file: str):
    lexer = get_lexer_by_name("C++")
    lexer.add_filter('raiseonerror')

    formatter = HtmlFormatter(linenos=False, linenostart=1)

    print(test_file)
    try:
        with open(test_file, "r") as f:
            source = f.read()
            highlight(source, lexer, formatter)
            print("Passed")
    except ErrorToken:
        logging.exception("Failed")


def main():
    this_dir = os.path.dirname(os.path.realpath(__file__))

    test_files = [
        # Broken since fc56ab883a80f6182339d7fbf95e531ff32e4809
        "camcopsapp.cpp",
        # Broken since c1a0d82acbe6fa026a1f6843fee00cc1df626549
        "convert.cpp",
        "databasemanager.cpp",
        "dumpsql.cpp",
        "emailvalidator.cpp",
        "whiskerconstants.cpp",
        "whiskertestmenu.cpp",
    ]

    for test_file in test_files:

        test_path = os.path.join(this_dir, test_file)
        test_highlight(test_path)


if __name__ == "__main__":
    main()
